window.Gleam.initSearch([{"doc":"hug","title":"hug","content":"# hug\n\nA package for creating helpful, and pretty CLI messages.\n\n[![Package Version](https://img.shields.io/hexpm/v/hug)](https://hex.pm/packages/hug)\n[![Hex Docs](https://img.shields.io/badge/hex-docs-ffaff3)](https://hexdocs.pm/hug/)\n\n✨ This project is written in pure Gleam so you can use it anywhere Gleam runs: Erlang, Elixir, Node, Deno, and the browser!\n\n&lt;pre&gt;\n&lt;span style=&quot;color:red;&quot;&gt;error&lt;/span&gt;: mismatched types \n  ┌─ example.gleam:2:3 \n  │    \n  │ let a = \n2 │   1 + &quot;hello&quot; \n  │   ~~~~~~~~~~~ \n  │ \n  \nexpected type `Num` got type `Str`\n&lt;/pre&gt;\n\n---\n\n## Quick start\n\n```gleam\nimport gleam/io\nimport hug\n\npub fn main() {\n  let source = &quot;let six = 5 + 1.0&quot;\n\n   source\n   |&gt; hug.error(\n     in: &quot;example.gleam&quot;,\n     from: #(1, 10),\n     to: #(1, 17),\n     message: &quot;invalid type&quot;,\n     hint: &quot;can not add an `Int` to a `Float`&quot;\n   )\n   |&gt; io.println_error()\n  )\n}\n```\n\n## Installation\n\nIf available on Hex this package can be added to your Gleam project:\n\n```sh\ngleam add hug\n```\n\nand its documentation can be found at &lt;https://hexdocs.pm/hug&gt;.\n\n\n## Why `hug`?\n\nThe name `hug` is inspired by Mark Rendle&#39;s talk [The Worst Programming Language Ever](https://youtu.be/vcFBwt1nu2U?t=2229) where he refers error messages in Rust as &quot;a hug from the compiler&quot;.\n","url":"index.html"},{"doc":"hug","title":"error","content":"pub fn error(\n  in file_name: String,\n  containing source: String,\n  from start: #(Int, Int),\n  to end: #(Int, Int),\n  message msg: String,\n  hint hint: String,\n) -&gt; String\n Returns a `String` displaying the provided error and relevant code.\n\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n fn example() {\n   let source = &quot;let five = 4 + 1.0&quot;\n   \n   source\n   |&gt; hug.error(\n     in: &quot;example.gleam&quot;,\n     from: #(1, 11),\n     to: #(1, 18),\n     message: &quot;invalid type&quot;,\n     hint: &quot;can not add an `Int` to a `Float`&quot;\n   )\n   |&gt; io.println()\n }\n \n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/brettkolodny/hug/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\nhug.error\nhug error","url":"hug.html#error"},{"doc":"hug","title":"info","content":"pub fn info(\n  in file_name: String,\n  containing source: String,\n  from start: #(Int, Int),\n  to end: #(Int, Int),\n  message msg: String,\n  hint hint: String,\n) -&gt; String\n Returns a `String` displaying the provided info and relevant code.\n\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n fn example() {\n   let source = &quot;try five = int.parse(&quot;4&quot;) |&gt; result.then(fn(v) { v + 1})&quot;\n   \n   source\n   |&gt; hug.info(\n     in: &quot;example.gleam&quot;,\n     from: #(1, 1),\n     to: #(1, 4),\n     message: &quot;use of deprecated code&quot;,\n     hint: &quot;`try` is marked as deprecated, check out `use`!&quot;\n   )\n   |&gt; io.println()\n }\n \n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/brettkolodny/hug/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\nhug.info\nhug info","url":"hug.html#info"},{"doc":"hug","title":"warning","content":"pub fn warning(\n  in file_name: String,\n  containing source: String,\n  from start: #(Int, Int),\n  to end: #(Int, Int),\n  message msg: String,\n  hint hint: String,\n) -&gt; String\n Returns a `String` displaying the provided warning and relevant code.\n\n\n &lt;details&gt;\n &lt;summary&gt;Example:&lt;/summary&gt;\n\n \n fn example() {\n   let source = &quot;let five = 4 + 1.0&quot;\n   \n   source\n   |&gt; hug.warning(\n     in: &quot;example.gleam&quot;,\n     from: #(1, 5),\n     to: #(1, 9),\n     message: &quot;unused variable&quot;,\n     hint: &quot;the variable `five` is declared but never used&quot;\n   )\n   |&gt; io.println()\n }\n \n &lt;/details&gt;\n\n &lt;div style=&quot;position: relative;&quot;&gt;\n     &lt;a style=&quot;position: absolute; left: 0;&quot; href=&quot;https://github.com/brettkolodny/hug/issues&quot;&gt;\n         &lt;small&gt;Spot a typo? Open an issue!&lt;/small&gt;\n     &lt;/a&gt;\n     &lt;a style=&quot;position: absolute; right: 0;&quot; href=&quot;#&quot;&gt;\n         &lt;small&gt;Back to top ↑&lt;/small&gt;\n     &lt;/a&gt;\n &lt;/div&gt;\n\nSynonyms:\nhug.warning\nhug warning","url":"hug.html#warning"},{"doc":"hug","title":"hug","content":" \n - **Outputs**\n   - [`error`](#error)\n   - [`warning`](#error)\n   - [`info`](#info)\n\n ---\n\n &lt;details&gt;\n &lt;summary&gt;The license of that package is produced below:&lt;/summary&gt;\n \n \n &gt; MIT License\n\n &gt; Permission is hereby granted, free of charge, to any person obtaining a copy\n of this software and associated documentation files (the &quot;Software&quot;), to deal\n in the Software without restriction, including without limitation the rights\n to use, copy, modify, merge, publish, distribute, sublicense, and/or sell\n copies of the Software, and to permit persons to whom the Software is\n furnished to do so, subject to the following conditions:\n\n &gt; The above copyright notice and this permission notice shall be included in all\n copies or substantial portions of the Software.\n &lt;/details&gt;\n","url":"hug.html"}]);